Stan Math Library: stan/math/prim/scal/err/check_less_or_equal.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_less_or_equal.hpp File Reference
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/scal/err/domain_error_vec.hpp>`
`#include <stan/math/prim/scal/meta/length.hpp>`
`#include <stan/math/prim/scal/meta/get.hpp>`
`#include <stan/math/prim/scal/meta/is_vector_like.hpp>`
`#include <stan/math/prim/scal/meta/VectorView.hpp>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_y , typename T_high >
bool | stan::math::check_less_or_equal (const char *function, const char *name, const T_y &y, const T_high &high)
| Return `true` if `y` is less or equal to `high`. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.